#!/usr/bin/env python

"""
test_amt
----------------------------------

Tests for `amt` module's wsman.py file
"""
import mock
import testtools

from amt import wsman


def fake_uuid4():
    return "00000000-1111-2222-3333-444455556666"


class BaseTestCase(testtools.TestCase):

    def assertXmlEqual(self, one, two):
        one = one.strip()
        two = two.strip()
        array1 = [x.strip() for x in str(one).split("\n")]
        array2 = [x.strip() for x in str(two).split("\n")]
        self.maxDiff = None
        self.assertEqual(array1, array2)


class TestXMLGen(BaseTestCase):

    @mock.patch('uuid.uuid4', fake_uuid4)
    def test_get_request(self):
        uri = 'http://10.42.0.50:16992/wsman'
        res = ('http://schemas.dmtf.org/wbem/wscim/1/cim-schema/2/'
               'CIM_AssociatedPowerManagementService')

        shouldbe = """<?xml version="1.0" encoding="UTF-8"?>
<s:Envelope xmlns:s="http://www.w3.org/2003/05/soap-envelope" xmlns:wsa="http://schemas.xmlsoap.org/ws/2004/08/addressing" xmlns:wsman="http://schemas.dmtf.org/wbem/wsman/1/wsman.xsd">
<s:Header>
<wsa:Action s:mustUnderstand="true">http://schemas.xmlsoap.org/ws/2004/09/transfer/Get</wsa:Action>
<wsa:To s:mustUnderstand="true">http://10.42.0.50:16992/wsman</wsa:To>
<wsman:ResourceURI s:mustUnderstand="true">http://schemas.dmtf.org/wbem/wscim/1/cim-schema/2/CIM_AssociatedPowerManagementService</wsman:ResourceURI>
<wsa:MessageID s:mustUnderstand="true">uuid:00000000-1111-2222-3333-444455556666</wsa:MessageID>
<wsa:ReplyTo>
<wsa:Address>http://schemas.xmlsoap.org/ws/2004/08/addressing/role/anonymous</wsa:Address>
</wsa:ReplyTo>
</s:Header>
<s:Body/>
</s:Envelope>"""  # noqa

        self.assertXmlEqual(wsman.get_request(uri, res), shouldbe)

    @mock.patch('uuid.uuid4', fake_uuid4)
    def test_change_boot_to_pxe_request(self):
        uri = 'http://10.42.0.50:16992/wsman'

        shouldbe = """<?xml version="1.0" encoding="UTF-8"?>
<s:Envelope xmlns:s="http://www.w3.org/2003/05/soap-envelope" xmlns:wsa="http://schemas.xmlsoap.org/ws/2004/08/addressing" xmlns:wsman="http://schemas.dmtf.org/wbem/wsman/1/wsman.xsd" xmlns:n1="http://schemas.dmtf.org/wbem/wscim/1/cim-schema/2/CIM_BootConfigSetting">
<s:Header>
<wsa:Action s:mustUnderstand="true">http://schemas.dmtf.org/wbem/wscim/1/cim-schema/2/CIM_BootConfigSetting/ChangeBootOrder</wsa:Action>
<wsa:To s:mustUnderstand="true">http://10.42.0.50:16992/wsman</wsa:To>
<wsman:ResourceURI s:mustUnderstand="true">http://schemas.dmtf.org/wbem/wscim/1/cim-schema/2/CIM_BootConfigSetting</wsman:ResourceURI>
<wsa:MessageID s:mustUnderstand="true">uuid:00000000-1111-2222-3333-444455556666</wsa:MessageID>
<wsa:ReplyTo>
    <wsa:Address>http://schemas.xmlsoap.org/ws/2004/08/addressing/role/anonymous</wsa:Address>
</wsa:ReplyTo>
<wsman:SelectorSet>
   <wsman:Selector Name="InstanceID">Intel(r) AMT: Boot Configuration 0</wsman:Selector>
</wsman:SelectorSet>
</s:Header>
<s:Body>
  <n1:ChangeBootOrder_INPUT>
     <n1:Source>
        <wsa:Address>http://schemas.xmlsoap.org/ws/2004/08/addressing/role/anonymous</wsa:Address>
        <wsa:ReferenceParameters>
            <wsman:ResourceURI>http://schemas.dmtf.org/wbem/wscim/1/cim-schema/2/CIM_BootSourceSetting</wsman:ResourceURI>
            <wsman:SelectorSet>
                <wsman:Selector wsman:Name="InstanceID">Intel(r) AMT: Force PXE Boot</wsman:Selector>
            </wsman:SelectorSet>
         </wsa:ReferenceParameters>
     </n1:Source>
   </n1:ChangeBootOrder_INPUT>
</s:Body></s:Envelope>"""  # noqa

        self.assertXmlEqual(wsman.change_boot_to_pxe_request(uri), shouldbe)

    def test_change_boot_order_request_invalid_boot_device(self):
        uri = 'http://10.42.0.50:16992/wsman'
        self.assertRaises(AssertionError,
                          wsman.change_boot_order_request,
                          uri, 'pxe2')


class TestFriendlyPowerState(testtools.TestCase):

    def test_power_on(self):
        self.assertEqual(wsman.friendly_power_state('2'), 'on')
        self.assertEqual(wsman.friendly_power_state(2), 'on')

    def test_power_off(self):
        self.assertEqual(wsman.friendly_power_state('8'), 'off')
        self.assertEqual(wsman.friendly_power_state(8), 'off')

    def test_standby(self):
        self.assertEqual(wsman.friendly_power_state('4'), 'standby')
        self.assertEqual(wsman.friendly_power_state(4), 'standby')

    def test_reboot(self):
        self.assertEqual(wsman.friendly_power_state('5'), 'reboot')
        self.assertEqual(wsman.friendly_power_state(5), 'reboot')

    def test_hibernate(self):
        self.assertEqual(wsman.friendly_power_state('7'), 'hibernate')
        self.assertEqual(wsman.friendly_power_state(7), 'hibernate')

    def test_unknown(self):
        self.assertEqual(wsman.friendly_power_state('42'), 'unknown')
        self.assertEqual(wsman.friendly_power_state(42), 'unknown')

    def test_non_integer(self):
        self.assertRaises(ValueError, wsman.friendly_power_state, 'not-a-number')


class TestAmt(testtools.TestCase):

    def test_something(self):
        pass

# Local Variables:
# turn off whitespace mode because xml is *so* long
# eval: (whitespace-mode -1)
# End:



# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

"""
test_hostdb
----------------------------------

Tests for `amt` module's wsman.py file
"""

import appdirs
import fixtures
import mock
import testtools

from amt import hostdb


class TestHostDB(testtools.TestCase):

    def setUp(self):
        super(TestHostDB, self).setUp()
        dirname = fixtures.TempDir()
        self.useFixture(dirname)
        self.out = self.useFixture(fixtures.StringStream('stdout'))
        self.useFixture(fixtures.MonkeyPatch('sys.stdout', self.out.stream))
        with mock.patch('appdirs.user_config_dir', return_value=dirname.path):
            self.db = hostdb.HostDB()

    @property
    def stdout(self):
        return self.out._details['stdout'].as_text()

    def test_list_servers(self):
        self.db.add_server("os1", "10.42.0.50", "foo")
        self.db.add_server("os2", "10.42.0.51", "foo")
        self.db.list_servers()
        self.assertEqual(self.stdout,
                        "Available servers (2):\n    os1\n    os2")

    def test_rm_servers(self):
        self.db.add_server("os1", "10.42.0.50", "foo")
        self.db.add_server("os2", "10.42.0.51", "foo")
        self.db.add_server("os3", "10.42.0.52", "foo")
        self.db.rm_server("os2")
        self.db.list_servers()
        self.assertEqual(self.stdout,
                        "Available servers (2):\n    os1\n    os3")

    def test_get_server(self):
        self.db.add_server("os1", "10.42.0.50", "foo")
        self.db.add_server("os2", "10.42.0.51", "foo")
        server = self.db.get_server("os1")
        self.assertEqual(server,
                         dict(host="10.42.0.50", passwd="foo"))



# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from six.moves import configparser
import os

import appdirs

appauthor = "sdague"
appname = "amtctrl"


class HostDB(object):
    def __init__(self):
        self.confdir = appdirs.user_config_dir(appname, appauthor)
        self.confname = os.path.join(self.confdir, 'hosts.cfg')
        self.config = configparser.ConfigParser()
        self.config.read(self.confname)

    def list_servers(self):
        print("Available servers (%d):" % len(self.config.sections()))
        for item in self.config.sections():
            print("    %s" % item)

    def add_server(self, name, host, passwd):
        self.config.add_section(name)
        self.config.set(name, 'host', host)
        self.config.set(name, 'passwd', passwd)
        # ensure the directory exists
        if not os.path.exists(self.confdir):
            os.makedirs(self.confdir, 0o770)

        with open(self.confname, 'w') as f:
            self.config.write(f)

    def rm_server(self, name):
        self.config.remove_section(name)

        with open(self.confname, 'w') as f:
            self.config.write(f)

    def get_server(self, name):
        if self.config.has_section(name):
            return {
                'host': self.config.get(name, 'host'),
                'passwd': self.config.get(name, 'passwd')
            }
        else:
            print("No config found for server (%s), "
                  "perhaps you need to add one via ``amtctrl add``")



#!/usr/bin/env python
# -*- coding: utf-8 -*-


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read().replace('.. :changelog:', '')

requirements = [
    'appdirs',
    'requests',
    'six',
]

test_requirements = [
    'mock'
    # TODO: put package test requirements here
]

setup(
    name='amt',
    version='0.8.0',
    description="Tools for interacting with Intel's AMT",
    long_description=readme + '\n\n' + history,
    author="Sean Dague",
    author_email='sean@dague.net',
    url='https://github.com/sdague/amt',
    packages=[
        'amt',
    ],
    package_dir={'amt':
                 'amt'},
    scripts=['bin/amtctrl'],
    include_package_data=True,
    install_requires=requirements,
    license="Apache",
    zip_safe=False,
    keywords='amt',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
    ],
    test_suite='tests',
    tests_require=test_requirements
)
